<?php

use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Component\Display;
use EventPortal\Domain\Component\Dropdown\Select;
use EventPortal\Domain\Component\Input\Text;
use EventPortal\Domain\Component\Option;
use EventPortal\Domain\Component\Section;
use EventPortal\Domain\Event\Handlers\SetAsUnpublished;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Form\Facades\Form;
use EventPortal\Domain\Handlers\CreateModel;
use EventPortal\Domain\Handlers\UpdateModel;
use EventPortal\Domain\Util\Status;
use EventPortal\Enums\InertiaMethod;

Form::make('event.create')
    ->addSaveHandler(new CreateModel)
    ->addSaveHandler(new SetAsUnpublished)
    ->addFields(function () {
        return [
            Section::make('Key Details')->fields([
                Text::make('Name')->rules(['required']),
                Text::make('Url')
                    ->rules(['required'])
                    ->placeholder('http://google.com/'),
                Select::make('Event type')
                    ->name('type')
                    ->placeholder('Please select an event type')
                    ->options([
                        Option::make('Congress'),
                        Option::make('Seminar'),
                    ]),
            ]),
            Section::make('Contact Details')->fields([
                Text::make('Phone'),
                Text::make('Email')->rules('email'),
            ]),
        ];
    })
    ->addActions(function () {
        return [
            Button::make('Cancel')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.event.index'),
            Button::make('Create Event')
                ->method(InertiaMethod::POST())
                ->route('admin.event.store'),
        ];
    });

Form::make('event.edit')
    ->addSaveHandler(new UpdateModel)
    ->addFields(function () {
        return [
            Section::make('Key Details')->fields([
                Text::make('Name')->rules(['required']),
                Text::make('Url')
                    ->rules(['required'])
                    ->placeholder(config('app.url')),
                Select::make('Event type')
                    ->name('type')
                    ->placeholder('Please select an event type')
                    ->options([
                        Option::make('Congress'),
                        Option::make('Seminar'),
                    ]),
            ]),
            Section::make('Contact Details')->fields([
                Text::make('Phone'),
                Text::make('Email')->rules('email'),
            ]),
            Select::make('Status')->options(Status::make('event')->forFilters()),
        ];
    })
    ->addActions(function (Event $event) {
        return [
            Button::make('Cancel')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.event.index'),
            Button::make('Update Event')
                ->method(InertiaMethod::POST())
                ->route('admin.event.update', ['event' => $event->id]),
        ];
    });

Form::make('event.show')
    ->addFields(function () {
        return [
            Section::make('Key Details')->fields([
                Display::make('Name'),
            ]),
            Section::make('Contact Details')->fields([
                Display::make('Phone'),
                Display::make('Email'),
            ]),
            Display::make('Status'),
        ];
    })
    ->addActions(function (Event $event) {
        return [
            Button::make('Cancel')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.event.index'),
            Button::make('Edit Event')
                ->method(InertiaMethod::VISIT())
                ->route('admin.event.edit', ['event' => $event->id]),
        ];
    });
