<?php

namespace EventPortal\Domain\Permission\Resources;

use EventPortal\Domain\Permission\Models\Group as GroupModel;
use EventPortal\Domain\Permission\Models\Permission;
use Illuminate\Database\Eloquent\Collection;
use Illuminate\Support\Arr;

class Group
{
    /**
     * @var string
     */
    protected $id;

    /**
     * @var string
     */
    protected $label;

    /**
     * @var array
     */
    protected $children;

    public function __construct(GroupModel $group, Collection $roles)
    {
        $this->id = $group->slug;
        $this->label = $group->name;
        $this->children = $group->permissions->map(function (Permission $permission) use ($roles): array {
            return [
                'id' => $permission->slug,
                'label' => $permission->name,
                'checked' => Arr::collapse($roles->map(function ($role) use ($permission): array {
                    return [$role->slug => $role->permissions->contains($permission)];
                })),
            ];
        });
    }

    public function toArray(): array
    {
        return [
            'id' => $this->id,
            'label' => $this->label,
            'children' => $this->children,
        ];
    }
}
