<?php

namespace EventPortal\Domain\Team\Models;

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\User\Models\User;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\MorphToMany;
use Illuminate\Support\Str;

class Team extends Model
{
    /** @var array<string> */
    protected $fillable = [
        'name',
        'slug',
        'description',
    ];

    public function users(): MorphToMany
    {
        return $this->morphedByMany(User::class, 'teamable');
    }

    public function events(): MorphToMany
    {
        return $this->morphedByMany(Event::class, 'teamable');
    }

    protected static function booted(): void
    {
        static::creating(static function (Team $team): void {
            /**
             * If no slug is set, create one from the name. (I'm guessing this
             * will be replaced at some point with a sluggable package)
             */
            $team->slug = $team->slug ?? Str::slug($team->name);
        });
    }
}
