<?php

namespace EventPortal\Http\Controllers\Admin;

use EventPortal\Domain\Event\Actions\DeleteTeam;
use EventPortal\Domain\Team\Models\Team;
use EventPortal\Domain\User\Models\User;
use EventPortal\Domain\Util\Breadcrumb;
use EventPortal\Http\Controllers\Controller;
use EventPortal\Http\Requests\TeamRequest;
use Illuminate\Http\RedirectResponse;
use Inertia\Inertia;
use Inertia\Response;

class TeamController extends Controller
{
    public function index(): Response
    {
        $teams = Team::all();

        return Inertia::render('Team/Index', compact('teams'));
    }

    public function create(): Response
    {
        $breadcrumbs = Breadcrumb::make()
            ->add('Teams', route('admin.team.index'))
            ->add('Create a team')
            ->get();

        $allUsers = User::select(['id', 'full_name as label'])
            ->orderBy('full_name')
            ->get();

        return Inertia::render('Team/Create', [
            'breadcrumbs' => $breadcrumbs,
            'allUsers' => $allUsers,
        ]);
    }

    public function store(TeamRequest $request): RedirectResponse
    {
        $team = Team::create($request->only([
            'name',
            'description',
        ]));

        $team->users()->attach($request->input('users'));

        return redirect()->route('admin.team.index');
    }

    public function edit(Team $team): Response
    {
        $breadcrumbs = Breadcrumb::make()
            ->add('Teams', route('admin.team.index'))
            ->add($team->name, route('admin.team.show', $team->id))
            ->get();

        $teamUsers = $team->users()
            ->orderBy('full_name')
            ->get();

        $allUsers = User::select(['id', 'full_name as label'])
            ->orderBy('full_name')
            ->get()
            ->diff($teamUsers); // Exclude current team users

        return Inertia::render('Team/Edit', [
            'team' => $team,
            'breadcrumbs' => $breadcrumbs,
            'allUsers' => $allUsers,
            'teamUsers' => $teamUsers,
        ]);
    }

    public function update(Team $team, TeamRequest $request): RedirectResponse
    {
        $team->update($request->only([
            'slug',
            'name',
            'description',
        ]));

        $team->users()->sync($request->input('users'));

        return redirect()->route('admin.team.index');
    }

    public function show(Team $team): Response
    {
        $breadcrumbs = Breadcrumb::make()
            ->add('Teams', route('admin.team.index'))
            ->add($team->name)
            ->get();

        return Inertia::render('Team/Show', [
            'team' => $team,
            'breadcrumbs' => $breadcrumbs,
        ]);
    }

    public function delete(Team $team, DeleteTeam $deleteTeam): RedirectResponse
    {
        $deleteTeam->execute($team);
        return redirect()->route('admin.team.index');
    }
}
