<?php

namespace EventPortal\Http\Controllers\Admin;

use EventPortal\Domain\Team\Models\Team;
use EventPortal\Domain\User\Models\User;
use EventPortal\Domain\Util\Breadcrumb;
use EventPortal\Http\Controllers\Controller;
use EventPortal\Http\Requests\UserRequest;
use Illuminate\Http\RedirectResponse;
use Inertia\Inertia;
use Inertia\Response;

class UserController extends Controller
{
    public function index(): Response
    {
        return Inertia::render('User/Index', [
            'users' => User::all(),
        ]);
    }

    public function create(): Response
    {
        $breadcrumbs = Breadcrumb::make()
            ->add('Users', route('admin.user.index'))
            ->add('Create a user')
            ->get();

        $allTeams = Team::select(['id', 'name as label'])
            ->orderBy('name')
            ->get();

        return Inertia::render('User/Create', [
            'breadcrumbs' => $breadcrumbs,
            'allTeams' => $allTeams,
        ]);
    }

    public function store(UserRequest $request): RedirectResponse
    {
        $user = User::create($request->only([
            'first_name',
            'last_name',
            'email',
        ]));

        $user->teams()->attach($request->input('teams'));

        return redirect()->route('admin.user.index');
    }

    public function edit(User $user): Response
    {
        $breadcrumbs = Breadcrumb::make()
            ->add('Users', route('admin.user.index'))
            ->add($user->first_name, route('admin.user.show', $user->id))
            ->get();

        $userTeams = $user->teams()
            ->orderBy('name')
            ->get();

        $allTeams = Team::select(['id', 'name as label'])
            ->orderBy('name')
            ->get()
            ->diff($userTeams); // Exclude current user teams

        return Inertia::render('User/Edit', [
            'user' => $user,
            'breadcrumbs' => $breadcrumbs,
            'allTeams' => $allTeams,
            'teamUsers' => $userTeams,
        ]);
    }

    public function update(User $user, UserRequest $request): RedirectResponse
    {
        $user->update($request->only([
            'first_name',
            'last_name',
            'email',
        ]));

        $user->teams()->sync($request->input('teams'));

        return redirect()->route('admin.user.index');
    }

    public function show(User $user): Response
    {
        $breadcrumbs = Breadcrumb::make()
            ->add('Users', route('admin.user.index'))
            ->add($user->name)
            ->get();

        return Inertia::render('User/Show', [
            'user' => $user,
            'breadcrumbs' => $breadcrumbs,
        ]);
    }

    public function delete(User $user): RedirectResponse
    {
        $user->delete();

        return redirect()->route('admin.user.index');
    }
}
