<?php

namespace EventPortal\Providers;

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Exceptions\Handler;
use EventPortal\Http\Middleware\CurrentTeam;
use Illuminate\Contracts\Debug\ExceptionHandler;
use Illuminate\Routing\Router;
use Illuminate\Support\Facades\Route;
use Illuminate\Support\ServiceProvider;
use Inertia\Inertia;

class AppServiceProvider extends ServiceProvider
{
    /** @var string */
    protected $root = __DIR__ . '/../..';

    public function boot(Router $router): void
    {
        $this->app->booted(function (): void {
            $this->loadRoutesFrom("{$this->root}/routes/routes.php");
        });

        $this->loadViewsFrom("{$this->root}/resources/views", 'EventPortal');

        $this->loadMigrationsFrom("{$this->root}/database/migrations");

        $this->loadFactoriesFrom("{$this->root}/database/factories");


        $this->app->bind(ExceptionHandler::class, Handler::class);

        $this->publishes([
            "{$this->root}/tables/delegate.php" => '/tables/delegates.php',
            "{$this->root}/tables/event.php" => '/tables/event.php',
            "{$this->root}/tables/event-delegate.php" => '/tables/event-delegate.php',
        ], 'tables');

        $this->publishes([
            "{$this->root}/forms/delegate.php" => '/forms/delegates.php',
            "{$this->root}/forms/event.php" => '/forms/event.php',
            "{$this->root}/forms/event-delegate.php" => '/forms/event-delegate.php',
        ], 'forms');

        $this->publishes([
            "{$this->root}/config/permission.php" => config_path('/permission.php'),
            "{$this->root}/config/state-machine.php" => config_path('/state-machine.php'),
        ], 'permissions');

        $this->app->bind(\Illuminate\Contracts\Debug\ExceptionHandler::class, \EventPortal\Exceptions\Handler::class);

        $router->aliasMiddleware('current-team', CurrentTeam::class);

        Inertia::setRootView('EventPortal::app');

        Inertia::share([
            'errors' => function () {
                return session('errors') ? session('errors')->getBag('default')->getMessages() : (object) [];
            },
        ]);

        Route::model('event', Event::class);
    }

    public function register(): void
    {
    }
}
