<?php

namespace EventPortal\Tests\Feature\Admin\Event;

use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Component\Input\Text;
use EventPortal\Domain\Component\Section;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Form\Facades\Form;
use EventPortal\Domain\User\Models\User;
use EventPortal\Enums\InertiaMethod;
use EventPortal\Tests\Support\Traits\InteractsWithTeams;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;
use Spatie\Snapshots\MatchesSnapshots;

class EventEditTest extends TestCase
{
    use DatabaseMigrations, InteractsWithTeams, MatchesSnapshots;

    /** @test **/
    public function can_edit_event()
    {
        $this->withoutExceptionHandling();
        $user = factory(User::class)->create();
        $event = factory(Event::class)->create(['name' => 'Hello World!']);
        $this->addToSameTeam([$user, $event]);

        Form::make('event.edit')
            ->addFields(function () {
                return [
                    Section::make('Key details')->fields([
                        Text::make('name'),
                    ]),
                ];
            })
            ->addActions(function (Event $event) {
                return [
                    Button::make('Cancel')
                        ->variant('secondary')
                        ->method(InertiaMethod::VISIT())
                        ->route('admin.event.index'),
                    Button::make('Update event')
                        ->method(InertiaMethod::POST())
                        ->route('admin.event.update', ['event' => $event]),
                ];
            });

        $this->assertMatchesJsonSnapshot(
            $this->actingAs($user)
                ->get(route('admin.event.edit', $event->id))->props()
        );
    }
}
