<?php

namespace EventPortal\Tests\Support\Traits;

use EventPortal\Domain\Component\Option;
use EventPortal\Domain\Delegate\Models\Delegate;
use EventPortal\Domain\Event\Enums\DelegateStatus;
use EventPortal\Domain\Event\Models\Event;
use Illuminate\Support\Arr;

trait InteractsWithEventDelegates
{
    public function assertEventHasDelegate(Event $event, Delegate $delegate, ?DelegateStatus $status = null): self
    {
        if ($status === null) {
            $status = DelegateStatus::candidate();
        }

        $status = Option::make($status->getName())->value($status->getValue())->toJson();

        $this->assertDatabaseHas('delegate_event', [
            'delegate_id' => $delegate->id,
            'event_id' => $event->id,
            'status' => $status,
        ]);

        return $this;
    }

    /**
     * @param Delegate|array<Delegate> $delegates
     */
    public function assertEventHasDelegates(Event $event, $delegates, ?DelegateStatus $status = null): self
    {
        foreach (Arr::wrap($delegates) as $delegate) {
            $this->assertEventHasDelegate($event, $delegate, $status);
        }

        return $this;
    }

    public function assertEventMissingDelegate(Event $event, Delegate $delegate, ?DelegateStatus $status = null): self
    {
        if ($status === null) {
            $status = DelegateStatus::candidate();
        }

        $status = Option::make($status->getName())->value($status->getValue())->toJson();

        $this->assertDatabaseMissing('delegate_event', [
            'delegate_id' => $delegate->id,
            'event_id' => $event->id,
            'status' => $status,
        ]);

        return $this;
    }

    /**
     * @param Delegate|array<Delegate> $delegates
     */
    public function assertEventMissingDelegates(Event $event, $delegates, ?DelegateStatus $status = null): self
    {
        foreach (Arr::wrap($delegates) as $delegate) {
            $this->assertEventMissingDelegate($event, $delegate, $status);
        }

        return $this;
    }
}
