<?php

namespace EventPortal\Tests\Unit\Models;

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Team\Models\Team;
use EventPortal\Domain\User\Models\User;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;

class TeamTest extends TestCase
{
    use DatabaseMigrations;

    /** @test **/
    public function has_events()
    {
        $team = factory(Team::class)->create();
        $eventInTeam = factory(Event::class)->create();
        $eventInTeam->teams()->sync($team->id);
        $eventNotInTeam = factory(Event::class)->create();
        $events = $team->events;

        $this->assertCount(1, $events);
        $this->assertContainsModel($eventInTeam, $events);
        $this->assertNotContainsModel($eventNotInTeam, $events);
    }

    /** @test **/
    public function has_users()
    {
        $team = factory(Team::class)->create();
        $userInTeam = factory(User::class)->create();
        $userInTeam->teams()->sync($team->id);
        $userNotInTeam = factory(User::class)->create();
        $users = $team->users;

        $this->assertCount(1, $users);
        $this->assertContainsModel($userInTeam, $users);
        $this->assertNotContainsModel($userNotInTeam, $users);
    }

    /** @test **/
    public function can_determine_whether_a_model_belongs_to_a_team()
    {
        $team = factory(Team::class)->create();
        $eventInTeam = factory(Event::class)->create();
        $eventInTeam->teams()->sync($team->id);
        $eventNotInTeam = factory(Event::class)->create();

        $this->assertTrue($eventInTeam->belongsToTeam($team));
        $this->assertFalse($eventNotInTeam->belongsToTeam($team));
    }

    /** @test **/
    public function can_determine_whether_two_models_are_in_the_same_team()
    {
        $team = factory(Team::class)->create();
        $event1InTeam = factory(Event::class)->create();
        $event2InTeam = factory(Event::class)->create();
        $team->events()->sync([
            $event1InTeam->id,
            $event2InTeam->id
        ]);
        $eventNotInTeam = factory(Event::class)->create();

        $this->assertTrue($event1InTeam->belongsToSameTeamAs($event2InTeam));
        $this->assertTrue($event2InTeam->belongsToSameTeamAs($event1InTeam));
        $this->assertFalse($eventNotInTeam->belongsToSameTeamAs($event1InTeam));
        $this->assertFalse($eventNotInTeam->belongsToSameTeamAs($event2InTeam));
    }
}
